| imbalSubdiv_A | R Documentation |
imbalSubdiv_A - Calculates the node imbalance value "centroid
angle" of a vertex which subdivides the edge (p,v) at
v+x \cdot (p-v) with x \in [0,1]. For example,
we can obtain the node imbalance value of v if x=0, and
x=0.5 would indicate a subdividing node exactly in the middle of
v and p.
Attention: If x=1, this function will not calculate the node imbalance
value of p with respect to its incoming edge but with respect to the
edge (p,v) itself. This enables us to estimate the
node imbalance integrals over the entire edge length.
imbalSubdiv_alpha - Calculates the node imbalance value "minimal
centroid angle" of a vertex which subdivides the edge (p,v) at
v+x \cdot (p-v) with x \in [0,1]. For example,
we can obtain the node imbalance value of v if x=0, and
x=0.5 would indicate a subdividing node exactly in the middle of
v and p.
Attention: If x=1, this function will not calculate the node imbalance
value of p with respect to its incoming edge but with respect to the
edge (p,v) itself. This enables us to estimate the
node imbalance integrals over the entire edge length.
angle3dVec - Calculates the angle in the interval [0,\pi]
between two 3D vectors a and b.
Note that the function returns 0 if one entry vector is (0,0,0).
imbalSubdiv_A(x, p, v, centr_v, centr_v_weight, edge_weight)
imbalSubdiv_alpha(x, p, v, centr_v, centr_v_weight, edge_weight)
angle3dVec(a, b)
x |
Numeric value |
p |
Numeric vector of size 3 (3D coordinates of parent node |
v |
Numeric vector of size 3 (3D coordinates of node |
centr_v |
Numeric vector of size 3 (3D coordinates of the centroid of
the pending subtree of node |
centr_v_weight |
Numeric value >=0 (weight of the pending subtree of
node |
edge_weight |
Numeric value >=0 (weight of the edge |
a |
Numeric vector of size 3 (e.g., 3D coordinates). |
b |
Numeric vector of size 3 (e.g., 3D coordinates). |
imbalSubdiv_A Numeric value \in [0,\pi] (higher values
indicate a higher degree of asymmetry).
imbalSubdiv_alpha Numeric value \in [0,\pi/2]
(higher values indicate a higher degree of asymmetry).
angle3dVec Numeric value in [0,\pi].
Sophie Kersting, Luise Kühn
imbalSubdiv_A(
x = 0.5, p = c(1, 0, 1), v = c(0, 0, 0), centr_v = c(0.5, 0, 0),
centr_v_weight = 1, edge_weight = 1
)
imbalSubdiv_alpha(
x = 0.5, p = c(1, 0, 1), v = c(0, 0, 0), centr_v = c(0.5, 0, 0),
centr_v_weight = 1, edge_weight = 1
)
angle3dVec(a = c(1, 0, 0), b = c(0, 1, 0)) # right angle = pi/2 = 1.5707...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.