| qsm2phylo3D | R Documentation |
qsm2phylo3D - Wrapper function that converts the output .mat-file of
the software treeQSM (version 2.0 or 2.4.x) to a rooted tree in phylo3D
format.
qsmList2phylo3D - Converts a list containing QSM data to a rooted
tree in phylo3D format.
qsm2phylo3D(file, version = "2.4.x", setConnection2zero = TRUE)
qsmList2phylo3D(qsm_list, setConnection2zero = TRUE)
file |
File name (with path if not located in working directory),
e.g.: |
version |
Specifies the version of the treeQSM .mat-file. Available
are |
setConnection2zero |
Logical value (default TRUE) indicating if the width of the edges, which connect two consecutive cylinders, should be set to zero. If FALSE, then the radius is set to the radius of the "child" cylinder. |
qsm_list |
List containing the QSM-data, with the attributes "radius", "length", "start", "axis", "parent" and "extension". |
qsm2phylo3D(file) A rooted tree in phylo3D format.
qsmList2phylo3D(qsmList) A rooted tree in phylo3D format.
Sophie Kersting
mat_file <- system.file("extdata", "exampleQSM.mat",
package = "treeDbalance"
)
new_phylo <- qsm2phylo3D(file = mat_file)
new_phylo <- qsmList2phylo3D(NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.