qsm2phylo3D(file) A rooted tree in phylo3D format.
qsmList2phylo3D(qsmList) A rooted tree in phylo3D format.
Arguments
file
File name (with path if not located in working directory),
e.g.:
"C:/...path.../myMatlabQSMfile.mat"
version
Specifies the version of the treeQSM .mat-file. Available
are
- "2.0" for version 2.0 and
- "2.4.x" for version 2.4.1 and 2.4.2.
setConnection2zero
Logical value (default TRUE) indicating if the
width of the edges, which connect two consecutive cylinders, should be
set to zero. If FALSE, then the radius is set to the radius of the
"child" cylinder.
qsm_list
List containing the QSM-data, with the attributes
"radius", "length", "start", "axis", "parent" and "extension".